%define major		22
%define	api		2.0
%define libname         %mklibname %{name} %{api} %{major}
%define develname	%mklibname %{name} -d

%define rlmajor		18
%define rlapi		18
%define rllibname	%mklibname %{name}readline %{rlapi} %{rlmajor}

Name:		guile
Version:	2.0.5
Release:	%mkrel 4
Summary:	GNU implementation of Scheme for application extensibility
License:	LGPLv2+
Group:		Development/Other
URL:		http://www.gnu.org/software/guile/guile.html
Source0:	ftp://ftp.gnu.org/pub/gnu/guile/guile-%{version}.tar.gz
Source1:	ftp://ftp.gnu.org/pub/gnu/guile/guile-%{version}.tar.gz.sig
Patch0:		guile-2.0.3-64bit-fixes.patch
Patch2:		guile-2.0.3-drop-ldflags-from-pkgconfig.patch
Patch10:	guile-2.0.5-turn-off-gc-test.patch
Patch11:	guile-2.0.3-mktemp.patch
BuildRequires:	libgmp-devel
BuildRequires:	libltdl-devel
BuildRequires:	libncurses-devel
BuildRequires:	libreadline-devel
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(bdw-gc)
# for srfi-19.test
BuildRequires:	timezone
BuildRequires:	chrpath
Conflicts:	guile1.8 >= 1.8.8-7

%package -n %{libname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries
Requires:	%{name}-runtime = %{version}-%{release}

%package -n %{rllibname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries

%package -n %{develname}
Summary:	Development headers and static library for libguile
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{rllibname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Conflicts:	%{_lib}guile1.8-devel >= 1.8.8-7

%package runtime
Summary:        Guile runtime library
Group:          System/Libraries
Conflicts:	%{name} < 2.0.5-2

%description
GUILE (GNU's Ubiquitous Intelligent Language for Extension) is a
library implementation of the Scheme programming language, written in
C. GUILE provides a machine-independent execution platform that can
be linked in as a library during the building of extensible programs.

Install the guile package if you'd like to add extensibility to
programs that you are developing. You'll also need to install the
guile-devel package.

%description -n %{libname}
This package contains Guile shared object libraries.

%description -n %{rllibname}
This package contains Guile shared object libraries.

%description -n %{develname}
This package contains the development headers and the static library
for libguile. C headers, aclocal macros, the `guile1.4-snarf' and
`guile-config' utilities, and static `libguile' library for Guile, the
GNU Ubiquitous Intelligent Language for Extension

%description runtime
This package contains Scheme runtime for GUILE, including ice-9
Scheme module.

%prep
%setup -q -n %{name}-%{version}
%apply_patches

#fix encodings
for i in libguile/ChangeLog*; do
	mv $i $i.old
	iconv -f ISO8859-1 -t UTF-8 $i.old -o $i
done

%build
autoreconf -vfi
%configure2_5x \
	--disable-error-on-warning \
	--disable-rpath \
	--disable-static \
	--with-threads \
	--with-pic

%make

%install
%makeinstall_std

#remove rpath
chrpath -d %{buildroot}%{_bindir}/%{name}

#we don't want these
find %{buildroot} -name "*.la" -delete

#for ghost files
touch %{buildroot}%{_datadir}/%{name}/%{api}/slibcat
touch %{buildroot}%{_datadir}/%{name}/%{api}/slib

#slib needs this
mkdir -p %{buildroot}%{_datadir}/guile/site

%if 0
%check
%make check
%endif

%post
%_install_info %{name}-tut.info
%_install_info %{name}.info
%_install_info r5rs.info
%_install_info goops.info

%preun
%_remove_install_info %{name}-tut.info
%_remove_install_info %{name}.info
%_remove_install_info r5rs.info
%_remove_install_info goops.info

%triggerin -- slib
ln -sfT ../../slib %{_datadir}/guile/%{api}/slib

rm -f %{_datadir}/guile/%{mver}/slibcat
export SCHEME_LIBRARY_PATH=%{_datadir}/slib/

# Build SLIB catalog
for pre in \
    "(use-modules (ice-9 slib))" \
    "(load \"%{_datadir}/slib/guile.init\")"
do
    %{_bindir}/guile -c "$pre
        (set! implementation-vicinity (lambda () \"%{_datadir}/guile/%{api}/\"))
        (require 'new-catalog)" &> /dev/null && break
    rm -f %{_datadir}/guile/%{api}/slibcat
done
:

%triggerun -- slib
if [ "$1" = 0 -o "$2" = 0 ]; then
    rm -f %{_datadir}/guile/%{api}/slib{,cat}
fi

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog GUILE-VERSION LICENSE README THANKS
%{_bindir}/%{name}
%{_bindir}/%{name}-tools
%{_bindir}/guild
%{_libdir}/%{name}
%exclude %{_libdir}/%{name}/%{api}
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/%{api}
%{_mandir}/man1/guile.1.*
%{_infodir}/*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/lib%{name}-%{api}.so.%{major}*

%files -n %{rllibname}
%defattr(-,root,root)
%{_libdir}/lib%{name}readline-v-%{rlapi}.so.%{rlmajor}*

%files -n %{develname}
%defattr(-,root,root)
%doc HACKING NEWS libguile/ChangeLog*
%{_bindir}/%{name}-config
%{_bindir}/%{name}-snarf
%{_datadir}/aclocal/*
%{_includedir}/%{name}
%{_libdir}/lib%{name}-%{api}.so
%{_libdir}/lib%{name}readline-v-%{rlapi}.so
%{_libdir}/pkgconfig/%{name}*.pc

%files runtime
%{_libdir}/%{name}/%{api}/*
%{_datadir}/%{name}/%{api}/*
# ugly workaround to not list files twice
%exclude %{_datadir}/%{name}/%{api}/slibcat
%exclude %{_datadir}/%{name}/%{api}/slib
%ghost %{_datadir}/%{name}/%{api}/slibcat
%ghost %{_datadir}/%{name}/%{api}/slib


%changelog

* Tue Apr 03 2012 mitya <mitya> 2.0.5-4.mga2
+ Revision: 228040
+ rebuild (emptylog)

* Mon Apr 02 2012 mitya <mitya> 2.0.5-2.mga2
+ Revision: 227981
- Split Guile runtime off the main package to make Guile 1.8/2.0 parallel installable

* Sun Feb 05 2012 wally <wally> 2.0.5-1.mga2
+ Revision: 204830
- new version 2.0.5
- rediff P10

* Wed Dec 28 2011 wally <wally> 2.0.3-2.mga2
+ Revision: 188446
- add triggerin and triggerun scripts back

* Wed Dec 28 2011 wally <wally> 2.0.3-1.mga2
+ Revision: 188386
- new version 2.0.3
- new major and api versions
- rediff P0 and P2
- sync patches with OpenSuse
- for now conflict with older guile1.8
- clean .spec

* Sun Nov 20 2011 dmorgan <dmorgan> 1.8.8-6.mga2
+ Revision: 170152
- Remove .la files

* Thu Jul 07 2011 ahmad <ahmad> 1.8.8-5.mga2
+ Revision: 119732
- Update to 1.8.8
- We don't have sparc or ppc ports
- Drop patch4 (testsuite2), fixed upstream

* Mon Apr 18 2011 rtp <rtp> 1.8.7-5.mga1
+ Revision: 87633
- backport fix for the build of the documentation

  + dmorgan <dmorgan>
    - Remove mdv macros
    - imported package guile

